@@ -12,7 +12,7 @@ index! {
 impl Dictionaries {
     #[doc(hidden)]
     pub fn into(self) -> Result<Vec<Operations>> {
-        let Dictionaries { index: Index { data, .. } } = self;
+        let Dictionaries(Index { data, .. }) = self;
         let mut vector = Vec::with_capacity(data.len());
         for chunk in data {
             vector.push(read_value!(&mut Cursor::new(chunk)));
